@@ -28,13 +28,11 @@
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdk.h>
 
-#include <thunar-vfs/thunar-vfs.h>
+#include <gio/gio.h>
+#include <gio/gdesktopappinfo.h>
 
 #include <libxfcegui4/libxfcegui4.h>
-
-#include <libxfce4panel/xfce-panel-window.h>
-#include <libxfce4panel/xfce-panel-plugin.h>
-#include <libxfce4panel/xfce-panel-convenience.h>
+#include <libxfce4panel/libxfce4panel.h>
 
 #include "linelight.h"
 #include "defines.h"
@@ -51,6 +49,7 @@ static void start_search(GtkEditable *entry,char* user_data);
 static void open_search_window_cb(GtkButton *button, XfcePanelPlugin* win);
 static gboolean tree_selection (GtkWidget *widget, GdkEventKey *event, GtkWidget *tree);
 static void cell_renderer (GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, GtkTreeModel *tree_model, GtkTreeIter *iter, gpointer data);
+static gboolean delete_event(GtkWidget *w, GdkEvent* event,  gpointer   user_data);
 
 /*
  *  GUI Handling
@@ -252,22 +251,33 @@ static void start_search(GtkEditable *entry, char *user_data)
 
 static void executeFile(char* path)
 {
-    ThunarVfsPath *thunarPath;
-    ThunarVfsInfo *info;
+    GFile           *file;
+    GFileInfo       *info;
+    GAppInfo        *app;
+    GDesktopAppInfo *desktop_app;
+    GList           *fileList = NULL;
 
-    thunarPath = thunar_vfs_path_new (path,NULL);
-    if (thunarPath == NULL)
-        return;
+    file = g_file_new_for_path (path);
+    if (file == NULL)
+         return;
 
-    info = thunar_vfs_info_new_for_path(thunarPath,NULL);
+    info = g_file_query_info (file, G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE, G_FILE_QUERY_INFO_NONE, NULL, NULL);
     if (info == NULL)
+    {
+        g_object_unref (file);
         return;
+    }
 
     if (strstr(path,".desktop") != 0)
     {
-        thunar_vfs_info_execute(info, NULL, NULL,NULL,NULL);
+        desktop_app = g_desktop_app_info_new_from_filename (path);
+        if (desktop_app != NULL)
+        {
+            g_app_info_launch (G_APP_INFO (desktop_app), NULL, NULL, NULL);
+            g_object_unref (desktop_app);
+        }
     }
-    else if (info->type == THUNAR_VFS_FILE_TYPE_DIRECTORY)
+    else if (g_file_query_file_type (file, G_FILE_QUERY_INFO_NONE, NULL) == G_FILE_TYPE_DIRECTORY)
     {
         char command[strlen(path) + 10];
         strcpy(command, "thunar \"");
@@ -277,23 +287,17 @@ static void executeFile(char* path)
     }
     else
     {
-        GList *pathList=NULL;
-        pathList = g_list_append(pathList,thunarPath);
+        fileList = g_list_append (fileList, file);
 
-        ThunarVfsMimeDatabase *db = thunar_vfs_mime_database_get_default();
-        ThunarVfsMimeInfo *info = thunar_vfs_mime_database_get_info_for_file(db, path,NULL);
-        ThunarVfsMimeApplication *app = thunar_vfs_mime_database_get_default_application(db,info);
+	app = g_app_info_get_default_for_type (g_file_info_get_content_type (info), FALSE);
 
-        thunar_vfs_mime_handler_exec (THUNAR_VFS_MIME_HANDLER(app),NULL, pathList, NULL);
+	g_app_info_launch (app, fileList, NULL, NULL);
 
-        g_object_unref(db);
-        thunar_vfs_mime_info_unref(info);
         g_object_unref(app);
-        g_list_free(pathList);
+        g_list_free(fileList);
     }
-    thunar_vfs_info_unref(info);
-    thunar_vfs_path_unref(thunarPath);
-
+    g_object_unref (info);
+    g_object_unref (file);
 }
 
 void* show_all_search_results(void* arg)
@@ -471,6 +475,12 @@ static gboolean esc_event(GtkWidget *w, GdkEventKey *event, GtkWidget *entry)
     return FALSE;
 }
 
+static gboolean delete_event(GtkWidget *w, GdkEvent* event,  gpointer   user_data)
+{
+    linelight_toggle_show_hide(linelight);
+    return TRUE;
+}
+
 /*
  *  About Dialog
  */
@@ -559,7 +569,6 @@ static void save_data_cb(XfcePanelPlugin *plugin, gpointer userdata)
 static void clean_up_cb(XfcePanelPlugin *plugin, gpointer userdata)
 {
     save_data_cb(plugin, userdata);
-    thunar_vfs_shutdown();
     linelight_free(linelight);
     system("rm -r /tmp/xfce4-linelight/");
     gdk_threads_leave ();
@@ -746,8 +755,7 @@ static void showProperties_cb(XfcePanelPlugin *plugin, gpointer userdata)
 int main (int argc, char *argv[])
 {
     g_type_init ();
-    thunar_vfs_init ();
-    //g_thread_init (NULL);
+    g_thread_init (NULL);
     gdk_threads_init();
     gdk_threads_enter();
 
@@ -772,7 +780,6 @@ int main (int argc, char *argv[])
 
 
     gtk_main ();
-    thunar_vfs_shutdown();
     gdk_threads_leave ();
     return 0;
 }
@@ -780,9 +787,8 @@ int main (int argc, char *argv[])
 // callback for xfce panel (executed on plugin addition)
 static void plugin_create(XfcePanelPlugin *plugin)
 {
-    g_type_init ();
-    thunar_vfs_init ();
-    //g_thread_init (NULL);
+    g_type_init ();   
+    g_thread_init (NULL);
     gdk_threads_init();
     gdk_threads_enter();
 
@@ -813,6 +819,7 @@ static void plugin_create(XfcePanelPlugin *plugin)
     GtkListStore *list = gtk_list_store_new(NUM_COLUMS,GDK_TYPE_PIXBUF, G_TYPE_STRING);
     linelight = linelight_new(text_window, list);
     gtk_container_add(GTK_CONTAINER(text_window), create_windows_content(list));
+    g_signal_connect(text_window, "delete-event", G_CALLBACK(delete_event), NULL);
 
     load_data(plugin,linelight);
     linelight_clear_list(linelight);
